==> vtigercrm-5.1.0.tgz: modules/ServiceContracts/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array (
'Service Contracts' => 'Service Contracts',
'ServiceContracts' => 'Service Contracts',
'SINGLE_ServiceContracts' => 'Service Contract',
'LBL_SERVICE_CONTRACT_INFORMATION' => 'Service Contract Information',
'LBL_CUSTOM_INFORMATION' => 'Custom Information',

'Contract No' => 'Contract No',
'Assigned To' => 'Assigned To',
'Created Time' => 'Created Time',
'Modified Time' => 'Modified Time',
'Start Date' => 'Start Date',
'Due Date' => 'Due Date',
'End Date' => 'End Date',
'Related to' => 'Related to',
'Tracking Unit' => 'Tracking Unit',
'Total Units' => 'Total Units',
'Used Units' => 'Used Units',
'Subject' => 'Subject',
'Progress'=> 'Progress (in %)',
'Type' => 'Type',
'Planned Duration' => 'Planned Duration (in Days)',
'Actual Duration' => 'Actual Duration (in Days)',
'Status' => 'Status',
'Priority' => 'Priority',

'Undefined' => 'Undefined',
'In Planning' => 'In Planning',
'In Progress' => 'In Progress',
'On Hold' => 'On Hold',
'Complete' => 'Complete',
'Archived' => 'Archived',

'Support' => 'Support',
'Services' => 'Services',
'Administrative' => 'Administrative',

'Low'=>'Low',
'Normal'=>'Normal',
'High'=>'High',

'None'=>'None',
'Hours'=>'Hours',
'Days'=>'Days',
'Incidents'=>'Incidents',

);

?>

==> vtigercrm-5.2.1.tgz: modules/ServiceContracts/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array (
'Service Contracts' => 'Service Contracts',
'ServiceContracts' => 'Service Contracts',
'SINGLE_ServiceContracts' => 'Service Contract',
'LBL_SERVICE_CONTRACT_INFORMATION' => 'Service Contract Information',
'LBL_CUSTOM_INFORMATION' => 'Custom Information',

'Contract No' => 'Contract No',
'Assigned To' => 'Assigned To',
'Created Time' => 'Created Time',
'Modified Time' => 'Modified Time',
'Start Date' => 'Start Date',
'Due date' => 'Due Date',
'End Date' => 'End Date',
'Related to' => 'Related to',
'Tracking Unit' => 'Tracking Unit',
'Total Units' => 'Total Units',
'Used Units' => 'Used Units',
'Subject' => 'Subject',
'Progress'=> 'Progress (in %)',
'Type' => 'Type',
'Planned Duration' => 'Planned Duration (in Days)',
'Actual Duration' => 'Actual Duration (in Days)',
'Status' => 'Status',
'Priority' => 'Priority',

'Undefined' => 'Undefined',
'In Planning' => 'In Planning',
'In Progress' => 'In Progress',
'On Hold' => 'On Hold',
'Complete' => 'Complete',
'Archived' => 'Archived',

'Support' => 'Support',
'Services' => 'Services',
'Administrative' => 'Administrative',

'Low'=>'Low',
'Normal'=>'Normal',
'High'=>'High',

'None'=>'None',
'Hours'=>'Hours',
'Days'=>'Days',
'Incidents'=>'Incidents',
/*
 * 5.2.0 changes 
 */
'LBL_MODULE_NAME'=>'Service Contracts',
);

?>
